//---------------------------------------------------------------------------

#ifndef ModVisFrmH
#define ModVisFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <CheckLst.hpp>
#include <ExtCtrls.hpp>
#include <swconfig.h>
#include <swmgr.h>
#include <ComCtrls.hpp>
//---------------------------------------------------------------------------
class TModVisForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel2;
	TPanel *Panel1;
	TBitBtn *OkBtn;
	TBitBtn *CancelBtn;
	TListView *modList;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
private:	// User declarations
public:		// User declarations
	ConfigEntMap *section;
     SWMgr *mgr;

	__fastcall TModVisForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TModVisForm *ModVisForm;
//---------------------------------------------------------------------------
#endif
